@@ -29,7 +29,7 @@ BASE_CONTRACTS_PATH = Path(__file__).parent / "data" / "contracts" / "ethereum"
 def captrace(capsys):
     class CapTrace:
         def read_trace(self, expected_start: str):
-            lines = capsys.readouterr().out.split("\n")
+            lines = capsys.readouterr().out.splitlines()
             start_index = 0
             for index, line in enumerate(lines):
                 if line.strip() == expected_start:
@@ -107,18 +107,25 @@ def test_mainnet_transaction_traces(mainnet_receipt, captrace):
     lines = captrace.read_trace("Call trace for")
     expected_beginning, expected_ending = EXPECTED_MAP[mainnet_receipt.txn_hash]
     actual_beginning = lines[:10]
-    actual_ending = lines[-11:]
+    actual_ending = lines[-10:]
     assert_rich_output(actual_beginning, expected_beginning)
     assert_rich_output(actual_ending, expected_ending)
 
 
 def assert_rich_output(rich_capture: List[str], expected: str):
-    expected_lines = [x.rstrip() for x in expected.split("\n") if x.rstrip()]
+    expected_lines = [x.rstrip() for x in expected.splitlines() if x.rstrip()]
     actual_lines = [x.rstrip() for x in rich_capture if x.rstrip()]
     assert actual_lines, "No output."
+    output = "\n".join(actual_lines)
 
     for actual, expected in zip(actual_lines, expected_lines):
-        fail_message = f"Pattern: {expected}, Line: {actual}"
+        fail_message = f"""\n
+        \tPattern: {expected},\n
+        \tLine   : {actual}\n
+        \n
+        Complete output:
+        \n{output}
+        """
         try:
             assert re.match(expected, actual), fail_message
         except AssertionError:
